# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/topocor',
                'doc_host': 'https://swalterfub.github.io',
                'git_url': 'https://github.com/swalterfub/topocor',
                'lib_path': 'topocor'},
  'syms': { 'topocor.core': { 'topocor.core.HelloSayer': ('core.html#hellosayer', 'topocor/core.py'),
                              'topocor.core.HelloSayer.__init__': ('core.html#hellosayer.__init__', 'topocor/core.py'),
                              'topocor.core.HelloSayer.say': ('core.html#hellosayer.say', 'topocor/core.py'),
                              'topocor.core.foo': ('core.html#foo', 'topocor/core.py'),
                              'topocor.core.say_hello': ('core.html#say_hello', 'topocor/core.py')}}}
